.. module:: enaml.widgets.separator

=======================
enaml.widgets.separator
=======================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    Separator


.. autoclass:: Separator
